@@ -11,11 +11,11 @@ use std::ptr;
 use std::sync::Mutex;
 
 pub struct WithLock<T> {
-	pub data: Mutex<T>,
+	pub(crate) data: Mutex<T>,
 }
 
 impl<T> WithLock<T> {
-	/// This function gives you access to what Mutex.lock().unwrap() would return.
+	/// This function gives you access to what `Mutex.lock().unwrap()` would return.
 	/// It will lock the Mutex, perform the closure, and then unlocks the Mutex.
 	/// This function is safe to use in async code, but can also be used in sync code.
 	/// ## Caveats
@@ -33,15 +33,15 @@ impl<T> WithLock<T> {
 	/// assert_eq!(a_lock + b_lock, 5);
 	/// let a_lock_2 = a.with_lock(|s| *s);
 	/// let b_lock_2 = b.with_lock(|s| *s);
-	/// assert_eq!(a_lock_2 + b_lock_2,5 );
+	/// assert_eq!(a_lock_2 + b_lock_2, 5);
 	///
 	/// ```
-	pub fn with_lock<F, U>(&self, func: F) -> U
+	pub fn with_lock<F, U>(&self, function: F) -> U
 	where
 		F: FnOnce(&mut T) -> U,
 	{
 		let lock = self.data.lock();
-		func(&mut *lock.unwrap())
+		function(&mut *lock.unwrap())
 	}
 
 	/// Construct the WithLock struct with a Mutex.
@@ -90,6 +90,16 @@ impl<T> MutexCell<T> {
 		self.data.with_lock(|s| *s)
 	}
 
+	/// The get_mut function. It gets the value inside the mutex and returns it as mutable.
+	/// ## What is going on
+	/// Locks the mutex and retrieves the value, then unlocks the mutex.
+	pub fn get_mut(&mut self) -> &mut T
+	where
+		T: Copy,
+	{
+		self.data.data.get_mut().unwrap()
+	}
+
 	/// The set function. It sets the value inside the mutex.
 	/// ## What is going on
 	/// Locks the mutex and updates the value, then unlocks the mutex.
@@ -113,6 +123,25 @@ impl<T> MutexCell<T> {
 		self.data
 			.with_lock(|a| new.data.with_lock(|b| mem::swap(a, b)))
 	}
+
+	/// The take function. It takes the value from the Mutex, returns it and sets the value to `Default::default()`
+	/// ## What is going on
+	/// Calls the `replace` function, and then sets it to `Default::default()`.
+
+	pub fn take(&self) -> T
+	where
+		T: Default,
+	{
+		self.replace(Default::default())
+	}
+
+	/// The into_inner function. It takes the Mutex and calls `into_inner` on it.
+	/// ## What is going on
+	/// It takes the Mutex and calls `into_inner` on it.
+
+	pub fn into_inner(self) -> T {
+		self.data.data.into_inner().unwrap()
+	}
 }
 
 #[cfg(doctest)]
@@ -166,4 +195,30 @@ mod tests {
 		c1.swap(&c1);
 		assert_eq!(c1.get(), 5);
 	}
+
+	#[test]
+	fn test_mutex_cell_get_mut() {
+		let mut c1 = MutexCell::new(5);
+		assert_eq!(c1.get(), 5);
+		let c2 = c1.get_mut();
+		*c2 += 1;
+		assert_eq!(c1.get(), 6);
+	}
+
+	#[test]
+	fn test_mutex_cell_take() {
+		let c = MutexCell::new(5);
+		let five = c.take();
+
+		assert_eq!(five, 5);
+		assert_eq!(c.into_inner(), 0);
+	}
+
+	#[test]
+	fn test_mutex_cell_into_inner() {
+		let c = MutexCell::new(5);
+		let five = c.into_inner();
+
+		assert_eq!(five, 5);
+	}
 }
